Class: PCPServerSDK::Models::BankAccountInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/PCP-server-Ruby-SDK/models/bank_account_information.rb

Overview

Object containing information about the end customer’s bank account.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BankAccountInformation

Initializes the object



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 48

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BankAccountInformation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BankAccountInformation`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'iban')
    self.iban = attributes[:'iban']
  else
    self.iban = nil
  end

  if attributes.key?(:'account_holder')
    self. = attributes[:'account_holder']
  else
    self. = nil
  end

  if attributes.key?(:'bic')
    self.bic = attributes[:'bic']
  end
end

Instance Attribute Details

#account_holderObject

Account holder of the bank account with the given IBAN. Does not necessarily have to be the end customer (e.g. joint accounts).



12
13
14
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 12

def 
  @account_holder
end

#bicObject

BIC (Bank Identification Code)



15
16
17
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 15

def bic
  @bic
end

#ibanObject

IBAN of the end customer’s bank account. The IBAN is the International Bank Account Number. It is an internationally agreed format for the BBAN and includes the ISO country code and two check digits.



9
10
11
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 9

def iban
  @iban
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 127

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PCPServerSDK::Models.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



27
28
29
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 27

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



18
19
20
21
22
23
24
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 18

def self.attribute_map
  {
    :'iban' => :'iban',
    :'account_holder' => :'accountHolder',
    :'bic' => :'bic'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 103

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



41
42
43
44
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 41

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



32
33
34
35
36
37
38
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 32

def self.openapi_types
  {
    :'iban' => :'String',
    :'account_holder' => :'String',
    :'bic' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



80
81
82
83
84
85
86
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 80

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      iban == o.iban &&
       == o. &&
      bic == o.bic
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 198

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


90
91
92
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 90

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



96
97
98
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 96

def hash
  [iban, , bic].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



174
175
176
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 174

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 180

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



168
169
170
# File 'lib/PCP-server-Ruby-SDK/models/bank_account_information.rb', line 168

def to_s
  to_hash.to_s
end