Class: PCPServerSDK::Models::CancelPaymentRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CancelPaymentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CancelPaymentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CancelPaymentRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cancellation_reason')
    self.cancellation_reason = attributes[:'cancellation_reason']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end
end

Instance Attribute Details

#amountObject

Here you can specify the amount that you want to cancel (specified in cents, where single digit currencies are presumed to have 2 digits). The amount can be lower than the amount that was authorized, but not higher. If left empty, the remaining open amount will be cancelled.



12
13
14
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 12

def amount
  @amount
end

#cancellation_reasonObject

Returns the value of attribute cancellation_reason.



7
8
9
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 7

def cancellation_reason
  @cancellation_reason
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 135

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PCPServerSDK::Models.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 45

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 37

def self.attribute_map
  {
    :'cancellation_reason' => :'cancellationReason',
    :'amount' => :'amount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 111

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
61
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 58

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 50

def self.openapi_types
  {
    :'cancellation_reason' => :'CancellationReason',
    :'amount' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



89
90
91
92
93
94
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 89

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cancellation_reason == o.cancellation_reason &&
      amount == o.amount
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 206

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


98
99
100
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 98

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



104
105
106
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 104

def hash
  [cancellation_reason, amount].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 182

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



176
177
178
# File 'lib/PCP-server-Ruby-SDK/models/cancel_payment_request.rb', line 176

def to_s
  to_hash.to_s
end