Class: PCPServerSDK::Models::MobilePaymentMethodSpecificInput

Inherits:
Object
  • Object
show all
Defined in:
lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MobilePaymentMethodSpecificInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `MobilePaymentMethodSpecificInput` initialize method"
  end

  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `MobilePaymentMethodSpecificInput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'payment_product_id')
    self.payment_product_id = attributes[:'payment_product_id']
  end

  if attributes.key?(:'authorization_mode')
    self.authorization_mode = attributes[:'authorization_mode']
  end

  if attributes.key?(:'encrypted_payment_data')
    self.encrypted_payment_data = attributes[:'encrypted_payment_data']
  end

  if attributes.key?(:'public_key_hash')
    self.public_key_hash = attributes[:'public_key_hash']
  end

  if attributes.key?(:'ephemeral_key')
    self.ephemeral_key = attributes[:'ephemeral_key']
  end

  if attributes.key?(:'three_d_secure')
    self.three_d_secure = attributes[:'three_d_secure']
  end

  if attributes.key?(:'payment_product302_specific_input')
    self.payment_product302_specific_input = attributes[:'payment_product302_specific_input']
  end

  if attributes.key?(:'payment_product5002_specific_input')
    self.payment_product5002_specific_input = attributes[:'payment_product5002_specific_input']
  end
end

Instance Attribute Details

#authorization_modeObject

Returns the value of attribute authorization_mode.



11
12
13
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 11

def authorization_mode
  @authorization_mode
end

#encrypted_payment_dataObject

The payment data if we will do the decryption of the encrypted payment data. Typically you’d use encryptedCustomerInput in the root of the create payment request to provide the encrypted payment data instead.



16
17
18
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 16

def encrypted_payment_data
  @encrypted_payment_data
end

#ephemeral_keyObject

Ephemeral Key A unique generated key used by Apple to encrypt data.



22
23
24
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 22

def ephemeral_key
  @ephemeral_key
end

#payment_product302_specific_inputObject

Returns the value of attribute payment_product302_specific_input.



27
28
29
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 27

def payment_product302_specific_input
  @payment_product302_specific_input
end

#payment_product5002_specific_inputObject

Returns the value of attribute payment_product5002_specific_input.



29
30
31
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 29

def payment_product5002_specific_input
  @payment_product5002_specific_input
end

#payment_product_idObject

Payment product identifier - please check product documentation for a full overview of possible values.



9
10
11
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 9

def payment_product_id
  @payment_product_id
end

#public_key_hashObject

Public Key Hash A unique identifier to retrieve key used by Apple to encrypt information.



19
20
21
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 19

def public_key_hash
  @public_key_hash
end

#three_d_secureObject

3D Secure authentication data



25
26
27
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 25

def three_d_secure
  @three_d_secure
end

Class Method Details

._deserialize(type, value) ⇒ Object



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 180

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else
    klass = PCPServerSDK::Models.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 68

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 54

def self.attribute_map
  {
    :'payment_product_id' => :'paymentProductId',
    :'authorization_mode' => :'authorizationMode',
    :'encrypted_payment_data' => :'encryptedPaymentData',
    :'public_key_hash' => :'publicKeyHash',
    :'ephemeral_key' => :'ephemeralKey',
    :'three_d_secure' => :'threeDSecure',
    :'payment_product302_specific_input' => :'paymentProduct302SpecificInput',
    :'payment_product5002_specific_input' => :'paymentProduct5002SpecificInput'
  }
end

.build_from_hash(attributes) ⇒ Object



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 162

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 73

def self.openapi_types
  {
    :'payment_product_id' => :'Integer',
    :'authorization_mode' => :'AuthorizationMode',
    :'encrypted_payment_data' => :'String',
    :'public_key_hash' => :'String',
    :'ephemeral_key' => :'String',
    :'three_d_secure' => :'MobilePaymentThreeDSecure',
    :'payment_product302_specific_input' => :'PaymentProduct302SpecificInput',
    :'payment_product5002_specific_input' => :'PaymentProduct5002SpecificInput'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      payment_product_id == o.payment_product_id &&
      authorization_mode == o.authorization_mode &&
      encrypted_payment_data == o.encrypted_payment_data &&
      public_key_hash == o.public_key_hash &&
      ephemeral_key == o.ephemeral_key &&
      three_d_secure == o.three_d_secure &&
      payment_product302_specific_input == o.payment_product302_specific_input &&
      payment_product5002_specific_input == o.payment_product5002_specific_input
end

#_to_hash(value) ⇒ Object



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 239

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Returns:

  • (Boolean)


154
155
156
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 154

def eql?(o)
  self == o
end

#hashObject



158
159
160
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 158

def hash
  [payment_product_id, authorization_mode, encrypted_payment_data, public_key_hash, ephemeral_key, three_d_secure, payment_product302_specific_input, payment_product5002_specific_input].hash
end

#to_bodyObject



221
222
223
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 221

def to_body
  to_hash
end

#to_hashObject



225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 225

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



217
218
219
# File 'lib/PCP-server-Ruby-SDK/models/mobile_payment_method_specific_input.rb', line 217

def to_s
  to_hash.to_s
end