Class: PCPServerSDK::Models::OrderLineDetailsInput
- Inherits:
-
Object
- Object
- PCPServerSDK::Models::OrderLineDetailsInput
- Defined in:
- lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#merchant_shop_delivery_reference ⇒ Object
Optional parameter to define the delivery shop or touchpoint where an item has been collected (e.g. for Click & Collect or Click & Reserve).
-
#product_category_path ⇒ Object
Category path of the item.
-
#product_code ⇒ Object
Product or UPC Code.
-
#product_image_url ⇒ Object
URL of a product image.
-
#product_name ⇒ Object
The name of the product, will be displayed in Portal if set.
-
#product_price ⇒ Object
The price of one unit of the product, the value should be zero or greater.
-
#product_type ⇒ Object
Returns the value of attribute product_type.
-
#product_url ⇒ Object
URL of the product in shop.
-
#quantity ⇒ Object
Quantity of the units being purchased, should be greater than zero Note: Must not be all spaces or all zeros.
-
#tax_amount ⇒ Object
Tax on the line item, with the last two digits implied as decimal places.
-
#tax_amount_per_unit ⇒ Object
This field indicates if the ‘taxAmount` is to be interpreted as the tax amount per unit rather than for the entire line item.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderLineDetailsInput
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OrderLineDetailsInput
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OrderLineDetailsInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OrderLineDetailsInput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'product_code') self.product_code = attributes[:'product_code'] end if attributes.key?(:'product_price') self.product_price = attributes[:'product_price'] else self.product_price = nil end if attributes.key?(:'product_type') self.product_type = attributes[:'product_type'] end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] else self.quantity = nil end if attributes.key?(:'tax_amount') self.tax_amount = attributes[:'tax_amount'] end if attributes.key?(:'tax_amount_per_unit') self.tax_amount_per_unit = attributes[:'tax_amount_per_unit'] else self.tax_amount_per_unit = false end if attributes.key?(:'product_url') self.product_url = attributes[:'product_url'] end if attributes.key?(:'product_image_url') self.product_image_url = attributes[:'product_image_url'] end if attributes.key?(:'product_category_path') self.product_category_path = attributes[:'product_category_path'] end if attributes.key?(:'merchant_shop_delivery_reference') self.merchant_shop_delivery_reference = attributes[:'merchant_shop_delivery_reference'] end if attributes.key?(:'product_name') self.product_name = attributes[:'product_name'] end end |
Instance Attribute Details
#merchant_shop_delivery_reference ⇒ Object
Optional parameter to define the delivery shop or touchpoint where an item has been collected (e.g. for Click & Collect or Click & Reserve).
35 36 37 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 35 def merchant_shop_delivery_reference @merchant_shop_delivery_reference end |
#product_category_path ⇒ Object
Category path of the item. Used for PAYONE Buy Now, Pay Later (BNPL).
32 33 34 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 32 def product_category_path @product_category_path end |
#product_code ⇒ Object
Product or UPC Code
9 10 11 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 9 def product_code @product_code end |
#product_image_url ⇒ Object
URL of a product image. Used for PAYONE Buy Now, Pay Later (BNPL).
29 30 31 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 29 def product_image_url @product_image_url end |
#product_name ⇒ Object
The name of the product, will be displayed in Portal if set.
38 39 40 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 38 def product_name @product_name end |
#product_price ⇒ Object
The price of one unit of the product, the value should be zero or greater.
12 13 14 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 12 def product_price @product_price end |
#product_type ⇒ Object
Returns the value of attribute product_type.
14 15 16 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 14 def product_type @product_type end |
#product_url ⇒ Object
URL of the product in shop. Used for PAYONE Buy Now, Pay Later (BNPL).
26 27 28 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 26 def product_url @product_url end |
#quantity ⇒ Object
Quantity of the units being purchased, should be greater than zero Note: Must not be all spaces or all zeros
17 18 19 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 17 def quantity @quantity end |
#tax_amount ⇒ Object
Tax on the line item, with the last two digits implied as decimal places
20 21 22 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 20 def tax_amount @tax_amount end |
#tax_amount_per_unit ⇒ Object
This field indicates if the ‘taxAmount` is to be interpreted as the tax amount per unit rather than for the entire line item. This field is included in the response only when `taxAmount` is set; otherwise, it will return as `null`.
23 24 25 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 23 def tax_amount_per_unit @tax_amount_per_unit end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 228 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PCPServerSDK::Models.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 80 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 63 def self.attribute_map { :'product_code' => :'productCode', :'product_price' => :'productPrice', :'product_type' => :'productType', :'quantity' => :'quantity', :'tax_amount' => :'taxAmount', :'tax_amount_per_unit' => :'taxAmountPerUnit', :'product_url' => :'productUrl', :'product_image_url' => :'productImageUrl', :'product_category_path' => :'productCategoryPath', :'merchant_shop_delivery_reference' => :'merchantShopDeliveryReference', :'product_name' => :'productName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 204 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 102 def self.openapi_nullable Set.new([]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 85 def self.openapi_types { :'product_code' => :'String', :'product_price' => :'Integer', :'product_type' => :'ProductType', :'quantity' => :'Integer', :'tax_amount' => :'Integer', :'tax_amount_per_unit' => :'Boolean', :'product_url' => :'String', :'product_image_url' => :'String', :'product_category_path' => :'String', :'merchant_shop_delivery_reference' => :'String', :'product_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 173 def ==(o) return true if self.equal?(o) self.class == o.class && product_code == o.product_code && product_price == o.product_price && product_type == o.product_type && quantity == o.quantity && tax_amount == o.tax_amount && tax_amount_per_unit == o.tax_amount_per_unit && product_url == o.product_url && product_image_url == o.product_image_url && product_category_path == o.product_category_path && merchant_shop_delivery_reference == o.merchant_shop_delivery_reference && product_name == o.product_name end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 299 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
191 192 193 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 191 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
197 198 199 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 197 def hash [product_code, product_price, product_type, quantity, tax_amount, tax_amount_per_unit, product_url, product_image_url, product_category_path, merchant_shop_delivery_reference, product_name].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
275 276 277 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 275 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 281 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
269 270 271 |
# File 'lib/PCP-server-Ruby-SDK/models/order_line_details_input.rb', line 269 def to_s to_hash.to_s end |