Class: PCPServerSDK::Models::PausePaymentRequest
- Inherits:
-
Object
- Object
- PCPServerSDK::Models::PausePaymentRequest
- Defined in:
- lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PausePaymentRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PausePaymentRequest
Initializes the object
30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 30 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PausePaymentRequest` initialize method" end attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PausePaymentRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 87 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else klass = PCPServerSDK::Models.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
14 15 16 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 14 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
9 10 11 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 9 def self.attribute_map {} end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 65 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
24 25 26 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 24 def self.openapi_nullable Set.new([]) end |
.openapi_types ⇒ Object
Attribute type mapping.
19 20 21 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 19 def self.openapi_types {} end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
45 46 47 48 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 45 def ==(o) return true if self.equal?(o) self.class == o.class end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 156 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
52 53 54 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 52 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
58 59 60 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 58 def hash [].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
132 133 134 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 132 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 138 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
126 127 128 |
# File 'lib/PCP-server-Ruby-SDK/models/pause_payment_request.rb', line 126 def to_s to_hash.to_s end |