Class: PCPServerSDK::Models::PaymentExecution
- Inherits:
-
Object
- Object
- PCPServerSDK::Models::PaymentExecution
- Defined in:
- lib/PCP-server-Ruby-SDK/models/payment_execution.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bank_payout_method_specific_input ⇒ Object
Returns the value of attribute bank_payout_method_specific_input.
-
#card_payment_method_specific_input ⇒ Object
Returns the value of attribute card_payment_method_specific_input.
-
#creation_date_time ⇒ Object
Returns the value of attribute creation_date_time.
-
#events ⇒ Object
Returns the value of attribute events.
-
#financing_payment_method_specific_input ⇒ Object
Returns the value of attribute financing_payment_method_specific_input.
-
#fund_splits ⇒ Object
Returns the value of attribute fund_splits.
-
#last_updated ⇒ Object
Returns the value of attribute last_updated.
-
#mobile_payment_method_specific_input ⇒ Object
Returns the value of attribute mobile_payment_method_specific_input.
-
#payment_channel ⇒ Object
Returns the value of attribute payment_channel.
-
#payment_execution_id ⇒ Object
Unique ID of paymentExecution.
-
#payment_id ⇒ Object
Unique payment transaction identifier of the payment gateway.
-
#previous_payment ⇒ Object
Returns the value of attribute previous_payment.
-
#redirect_payment_method_specific_input ⇒ Object
Returns the value of attribute redirect_payment_method_specific_input.
-
#references ⇒ Object
Returns the value of attribute references.
-
#sepa_direct_debit_payment_method_specific_input ⇒ Object
Returns the value of attribute sepa_direct_debit_payment_method_specific_input.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Object
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentExecution
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentExecution
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PaymentExecution` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PaymentExecution`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'payment_execution_id') self.payment_execution_id = attributes[:'payment_execution_id'] end if attributes.key?(:'payment_id') self.payment_id = attributes[:'payment_id'] end if attributes.key?(:'card_payment_method_specific_input') self.card_payment_method_specific_input = attributes[:'card_payment_method_specific_input'] end if attributes.key?(:'mobile_payment_method_specific_input') self.mobile_payment_method_specific_input = attributes[:'mobile_payment_method_specific_input'] end if attributes.key?(:'redirect_payment_method_specific_input') self.redirect_payment_method_specific_input = attributes[:'redirect_payment_method_specific_input'] end if attributes.key?(:'sepa_direct_debit_payment_method_specific_input') self.sepa_direct_debit_payment_method_specific_input = attributes[:'sepa_direct_debit_payment_method_specific_input'] end if attributes.key?(:'financing_payment_method_specific_input') self.financing_payment_method_specific_input = attributes[:'financing_payment_method_specific_input'] end if attributes.key?(:'bank_payout_method_specific_input') self.bank_payout_method_specific_input = attributes[:'bank_payout_method_specific_input'] end if attributes.key?(:'payment_channel') self.payment_channel = attributes[:'payment_channel'] end if attributes.key?(:'references') self.references = attributes[:'references'] end if attributes.key?(:'previous_payment') self.previous_payment = attributes[:'previous_payment'] end if attributes.key?(:'creation_date_time') self.creation_date_time = attributes[:'creation_date_time'] end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'fund_splits') if (value = attributes[:'fund_splits']).is_a?(Array) self.fund_splits = value end end end |
Instance Attribute Details
#bank_payout_method_specific_input ⇒ Object
Returns the value of attribute bank_payout_method_specific_input.
25 26 27 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 25 def bank_payout_method_specific_input @bank_payout_method_specific_input end |
#card_payment_method_specific_input ⇒ Object
Returns the value of attribute card_payment_method_specific_input.
15 16 17 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 15 def card_payment_method_specific_input @card_payment_method_specific_input end |
#creation_date_time ⇒ Object
Returns the value of attribute creation_date_time.
33 34 35 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 33 def creation_date_time @creation_date_time end |
#events ⇒ Object
Returns the value of attribute events.
37 38 39 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 37 def events @events end |
#financing_payment_method_specific_input ⇒ Object
Returns the value of attribute financing_payment_method_specific_input.
23 24 25 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 23 def financing_payment_method_specific_input @financing_payment_method_specific_input end |
#fund_splits ⇒ Object
Returns the value of attribute fund_splits.
39 40 41 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 39 def fund_splits @fund_splits end |
#last_updated ⇒ Object
Returns the value of attribute last_updated.
35 36 37 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 35 def last_updated @last_updated end |
#mobile_payment_method_specific_input ⇒ Object
Returns the value of attribute mobile_payment_method_specific_input.
17 18 19 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 17 def mobile_payment_method_specific_input @mobile_payment_method_specific_input end |
#payment_channel ⇒ Object
Returns the value of attribute payment_channel.
27 28 29 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 27 def payment_channel @payment_channel end |
#payment_execution_id ⇒ Object
Unique ID of paymentExecution.
10 11 12 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 10 def payment_execution_id @payment_execution_id end |
#payment_id ⇒ Object
Unique payment transaction identifier of the payment gateway.
13 14 15 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 13 def payment_id @payment_id end |
#previous_payment ⇒ Object
Returns the value of attribute previous_payment.
31 32 33 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 31 def previous_payment @previous_payment end |
#redirect_payment_method_specific_input ⇒ Object
Returns the value of attribute redirect_payment_method_specific_input.
19 20 21 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 19 def redirect_payment_method_specific_input @redirect_payment_method_specific_input end |
#references ⇒ Object
Returns the value of attribute references.
29 30 31 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 29 def references @references end |
#sepa_direct_debit_payment_method_specific_input ⇒ Object
Returns the value of attribute sepa_direct_debit_payment_method_specific_input.
21 22 23 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 21 def sepa_direct_debit_payment_method_specific_input @sepa_direct_debit_payment_method_specific_input end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 257 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PCPServerSDK::Models.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 85 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 64 def self.attribute_map { :'payment_execution_id' => :'paymentExecutionId', :'payment_id' => :'paymentId', :'card_payment_method_specific_input' => :'cardPaymentMethodSpecificInput', :'mobile_payment_method_specific_input' => :'mobilePaymentMethodSpecificInput', :'redirect_payment_method_specific_input' => :'redirectPaymentMethodSpecificInput', :'sepa_direct_debit_payment_method_specific_input' => :'sepaDirectDebitPaymentMethodSpecificInput', :'financing_payment_method_specific_input' => :'financingPaymentMethodSpecificInput', :'bank_payout_method_specific_input' => :'bankPayoutMethodSpecificInput', :'payment_channel' => :'paymentChannel', :'references' => :'references', :'previous_payment' => :'previousPayment', :'creation_date_time' => :'creationDateTime', :'last_updated' => :'lastUpdated', :'events' => :'events', :'fund_splits' => :'fundSplits' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 233 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 111 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 90 def self.openapi_types { :'payment_execution_id' => :'String', :'payment_id' => :'String', :'card_payment_method_specific_input' => :'CardPaymentMethodSpecificInput', :'mobile_payment_method_specific_input' => :'MobilePaymentMethodSpecificInput', :'redirect_payment_method_specific_input' => :'RedirectPaymentMethodSpecificInput', :'sepa_direct_debit_payment_method_specific_input' => :'SepaDirectDebitPaymentMethodSpecificInput', :'financing_payment_method_specific_input' => :'FinancingPaymentMethodSpecificInput', :'bank_payout_method_specific_input' => :'BankPayoutMethodSpecificInput', :'payment_channel' => :'PaymentChannel', :'references' => :'References', :'previous_payment' => :'String', :'creation_date_time' => :'Time', :'last_updated' => :'Time', :'events' => :'Array<PaymentEvent>', :'fund_splits' => :'Array<FundSplit>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 197 def ==(o) return true if self.equal?(o) self.class == o.class && payment_execution_id == o.payment_execution_id && payment_id == o.payment_id && card_payment_method_specific_input == o.card_payment_method_specific_input && mobile_payment_method_specific_input == o.mobile_payment_method_specific_input && redirect_payment_method_specific_input == o.redirect_payment_method_specific_input && sepa_direct_debit_payment_method_specific_input == o.sepa_direct_debit_payment_method_specific_input && financing_payment_method_specific_input == o.financing_payment_method_specific_input && bank_payout_method_specific_input == o.bank_payout_method_specific_input && payment_channel == o.payment_channel && references == o.references && previous_payment == o.previous_payment && creation_date_time == o.creation_date_time && last_updated == o.last_updated && events == o.events && fund_splits == o.fund_splits end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 328 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
218 219 220 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 218 def eql?(o) self == o end |
#hash ⇒ Object
Calculates hash code according to all attributes.
223 224 225 226 227 228 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 223 def hash [payment_execution_id, payment_id, card_payment_method_specific_input, mobile_payment_method_specific_input, redirect_payment_method_specific_input, sepa_direct_debit_payment_method_specific_input, financing_payment_method_specific_input, bank_payout_method_specific_input, payment_channel, references, previous_payment, creation_date_time, last_updated, events, fund_splits].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
304 305 306 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 304 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
298 299 300 |
# File 'lib/PCP-server-Ruby-SDK/models/payment_execution.rb', line 298 def to_s to_hash.to_s end |