Class: PCPServerSDK::Models::RedirectPaymentMethodSpecificInput
- Inherits:
-
Object
- Object
- PCPServerSDK::Models::RedirectPaymentMethodSpecificInput
- Defined in:
- lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb
Instance Attribute Summary collapse
-
#payment_processing_token ⇒ Object
ID of the token to use to create the payment.
-
#payment_product840_specific_input ⇒ Object
Returns the value of attribute payment_product840_specific_input.
-
#payment_product900_specific_input ⇒ Object
Returns the value of attribute payment_product900_specific_input.
-
#payment_product_id ⇒ Object
Payment product identifier - please check product documentation for a full overview of possible values.
-
#redirection_data ⇒ Object
Returns the value of attribute redirection_data.
-
#reporting_token ⇒ Object
Token to identify the card in the reporting.
-
#requires_approval ⇒ Object
-
true = the payment requires approval before the funds will be captured using the Approve payment or Capture payment API * false = the payment does not require approval, and the funds will be captured automatically If the parameter is not provided in the request, the default value will be true.
-
-
#tokenize ⇒ Object
Indicates if this transaction should be tokenized * true - Tokenize the transaction.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RedirectPaymentMethodSpecificInput
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RedirectPaymentMethodSpecificInput
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RedirectPaymentMethodSpecificInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RedirectPaymentMethodSpecificInput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'requires_approval') self.requires_approval = attributes[:'requires_approval'] end if attributes.key?(:'payment_processing_token') self.payment_processing_token = attributes[:'payment_processing_token'] end if attributes.key?(:'reporting_token') self.reporting_token = attributes[:'reporting_token'] end if attributes.key?(:'tokenize') self.tokenize = attributes[:'tokenize'] end if attributes.key?(:'payment_product_id') self.payment_product_id = attributes[:'payment_product_id'] end if attributes.key?(:'payment_product840_specific_input') self.payment_product840_specific_input = attributes[:'payment_product840_specific_input'] end if attributes.key?(:'payment_product900_specific_input') self.payment_product900_specific_input = attributes[:'payment_product900_specific_input'] end if attributes.key?(:'redirection_data') self.redirection_data = attributes[:'redirection_data'] end end |
Instance Attribute Details
#payment_processing_token ⇒ Object
ID of the token to use to create the payment.
13 14 15 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 13 def payment_processing_token @payment_processing_token end |
#payment_product840_specific_input ⇒ Object
Returns the value of attribute payment_product840_specific_input.
24 25 26 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 24 def payment_product840_specific_input @payment_product840_specific_input end |
#payment_product900_specific_input ⇒ Object
Returns the value of attribute payment_product900_specific_input.
26 27 28 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 26 def payment_product900_specific_input @payment_product900_specific_input end |
#payment_product_id ⇒ Object
Payment product identifier - please check product documentation for a full overview of possible values.
22 23 24 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 22 def payment_product_id @payment_product_id end |
#redirection_data ⇒ Object
Returns the value of attribute redirection_data.
28 29 30 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 28 def redirection_data @redirection_data end |
#reporting_token ⇒ Object
Token to identify the card in the reporting.
16 17 18 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 16 def reporting_token @reporting_token end |
#requires_approval ⇒ Object
-
true = the payment requires approval before the funds will be captured using the Approve payment or Capture payment API * false = the payment does not require approval, and the funds will be captured automatically If the parameter is not provided in the request, the default value will be true
10 11 12 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 10 def requires_approval @requires_approval end |
#tokenize ⇒ Object
Indicates if this transaction should be tokenized * true - Tokenize the transaction. * false - Do not tokenize the transaction, unless it would be tokenized by other means such as auto- tokenization of recurring payments. example: false
19 20 21 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 19 def tokenize @tokenize end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 171 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PCPServerSDK::Models.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 45 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 31 def self.attribute_map { :'requires_approval' => :'requiresApproval', :'payment_processing_token' => :'paymentProcessingToken', :'reporting_token' => :'reportingToken', :'tokenize' => :'tokenize', :'payment_product_id' => :'paymentProductId', :'payment_product840_specific_input' => :'paymentProduct840SpecificInput', :'payment_product900_specific_input' => :'paymentProduct900SpecificInput', :'redirection_data' => :'redirectionData' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 147 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 50 def self.openapi_types { :'requires_approval' => :'Boolean', :'payment_processing_token' => :'String', :'reporting_token' => :'String', :'tokenize' => :'Boolean', :'payment_product_id' => :'Integer', :'payment_product840_specific_input' => :'RedirectPaymentProduct840SpecificInput', :'payment_product900_specific_input' => :'RedirectPaymentProduct900SpecificInput', :'redirection_data' => :'RedirectionData' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 119 def ==(o) return true if self.equal?(o) self.class == o.class && requires_approval == o.requires_approval && payment_processing_token == o.payment_processing_token && reporting_token == o.reporting_token && tokenize == o.tokenize && payment_product_id == o.payment_product_id && payment_product840_specific_input == o.payment_product840_specific_input && payment_product900_specific_input == o.payment_product900_specific_input && redirection_data == o.redirection_data end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 242 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
134 135 136 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 134 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
140 141 142 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 140 def hash [requires_approval, payment_processing_token, reporting_token, tokenize, payment_product_id, payment_product840_specific_input, payment_product900_specific_input, redirection_data].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
218 219 220 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 218 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/PCP-server-Ruby-SDK/models/redirect_payment_method_specific_input.rb', line 212 def to_s to_hash.to_s end |